You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@arrow.apache.org by as...@apache.org on 2024/01/16 03:39:01 UTC

(arrow) branch main updated: GH-39624: [R][CI] Add CMake to docker file and update envvars (#39625)

This is an automated email from the ASF dual-hosted git repository.

assignuser pushed a commit to branch main
in repository https://gitbox.apache.org/repos/asf/arrow.git


The following commit(s) were added to refs/heads/main by this push:
     new ac50918a63 GH-39624: [R][CI] Add CMake to docker file and update envvars (#39625)
ac50918a63 is described below

commit ac50918a63f13088a5ea9e6c27a9fadbbb19d53f
Author: Jacob Wujciak-Jens <ja...@wujciak.de>
AuthorDate: Tue Jan 16 04:38:55 2024 +0100

    GH-39624: [R][CI] Add CMake to docker file and update envvars (#39625)
    
    ### Rationale for this change
    
    CMake is now a sysreq and we don't want to default to using nightly builds in CI
    
    ### Are these changes tested?
    
    Crossbos
    * Closes: #39624
    
    Authored-by: Jacob Wujciak-Jens <ja...@wujciak.de>
    Signed-off-by: Jacob Wujciak-Jens <ja...@wujciak.de>
---
 ci/scripts/r_docker_configure.sh | 5 +++--
 docker-compose.yml               | 3 ++-
 2 files changed, 5 insertions(+), 3 deletions(-)

diff --git a/docker-compose.yml b/docker-compose.yml
index 39cd473c27..14eff67f38 100644
--- a/docker-compose.yml
+++ b/docker-compose.yml
@@ -1414,6 +1414,7 @@ services:
       ARROW_DEPENDENCY_SOURCE: ''
       ARROW_SOURCE_HOME: '/arrow'
       FORCE_BUNDLED_BUILD: 'true'
+      LIBARROW_BINARY: 'false'
       LIBARROW_BUILD: 'true'
     extends: ubuntu-r
     command: >
@@ -1443,7 +1444,7 @@ services:
     shm_size: *shm-size
     environment:
       <<: [*common, *sccache]
-      LIBARROW_DOWNLOAD: "false"
+      LIBARROW_BINARY: "false"
       ARROW_SOURCE_HOME: "/arrow"
       ARROW_R_DEV: ${ARROW_R_DEV}
       # To test for CRAN release, delete ^^ these two env vars so we download the Apache release
diff --git a/ci/scripts/r_docker_configure.sh b/ci/scripts/r_docker_configure.sh
index 1cbd5f0b5e..52db2e6df6 100755
--- a/ci/scripts/r_docker_configure.sh
+++ b/ci/scripts/r_docker_configure.sh
@@ -91,8 +91,9 @@ if [ -f "${ARROW_SOURCE_HOME}/ci/scripts/r_install_system_dependencies.sh" ]; th
   "${ARROW_SOURCE_HOME}/ci/scripts/r_install_system_dependencies.sh"
 fi
 
-# Install rsync for bundling cpp source and curl to make sure it is installed on all images
-$PACKAGE_MANAGER install -y rsync curl
+# Install rsync for bundling cpp source and curl to make sure it is installed on all images,
+# cmake is now a listed sys req.
+$PACKAGE_MANAGER install -y rsync cmake curl
 
 # Workaround for html help install failure; see https://github.com/r-lib/devtools/issues/2084#issuecomment-530912786
 Rscript -e 'x <- file.path(R.home("doc"), "html"); if (!file.exists(x)) {dir.create(x, recursive=TRUE); file.copy(system.file("html/R.css", package="stats"), x)}'